Module sync_handler

Module sync_handler 

A type-erased synchronous handler.

Structs

SyncHandler
Type-erased synchronous handler wrapper.

Traits

WithSubState
A state whose states map is the leading field (offset 0) and whose duel field follows at the same offset as SubState’s, so that &mut Self can be reinterpreted as &mut SubState.

Functions

assert_sync_handler_layout
Assert the layout of SyncHandler is identical across two state types.