SyncHandler

Struct SyncHandler 

pub struct SyncHandler<Req, State, Res> {
    pub name: &'static str,
    pub module_name: &'static str,
    /* private fields */
}
Type-erased synchronous handler wrapper.

Uses raw pointers and monomorphized function pointers to achieve type erasure without requiring 'static bounds on Req, State, Res, or the handler’s type parameter T. It gives up the async nature of Handler (its future is always Ready), in exchange boxing nothing per call and enabling the dual-state trick (WithSubState).

The caller is responsible for ensuring soundness.

Fields

name: &'static str

The handler’s name. It is often function name.

module_name: &'static str

The module the handler was registered from. It is often produced by module_path!().

Implementations

Source

impl<Req, State, Res> SyncHandler<Req, State, Res>
where Req: Send, State: Send, Res: Send,

pub fn new<T, H: Handler<T, Req, State, Res, Future = Ready<Option<Res>>>>( priority: u8, name: &'static str, module_name: &'static str, handler: H, ) -> Self

Create a synchronous handler.