pub struct All { /* private fields */ }Expand description
A pure flag whose only meaning is its name.
Used as a handler key it resolves to 0, letting the call site register
the handler as a global one via register_global.